@@ -1,6 +1,7 @@
 from mongoengine import *
 from cryptomodel.operations import OPERATIONS
 
+
 class EUR(EmbeddedDocument):
     meta = {'strict': False}
     price = FloatField()
@@ -24,10 +25,12 @@ class Coin(EmbeddedDocument):
     symbol = StringField()
     quote = EmbeddedDocumentField(EURQuote, db_field='quote')
 
+
 class Status(EmbeddedDocument):
     meta = {'strict': False}
     timestamp = IntField()
 
+
 class prices(Document):
     meta = {'strict': False}
     coins = EmbeddedDocumentListField(Coin, db_field='data')
@@ -35,3 +38,9 @@ class prices(Document):
     source_id = ObjectIdField()
     operation = StringField(choices=OPERATIONS.choices())
 
+    def __init__(self, coins, status, source_id, operation, *args, **kwargs):
+        super(prices, self).__init__(*args, **kwargs)
+        self.coins = coins
+        self.status = status
+        self.source_id = source_id
+        self.operation = operation
