@@ -2,7 +2,7 @@ import jsonpickle
 from mongoengine import *
 
 from calculator.helpers import if_none_raise
-from cryptomodel import computed_notification
+from cryptomodel.computed_notification import computed_notification
 from cryptomodel.notification_type import NOTIFICATION_TYPE
 
 '''
@@ -14,6 +14,4 @@ Extends with sent flag and sent_date
 
 class sent_notification(computed_notification):
     meta = {'strict': False}
-
-    sent = BooleanField(default=False)
     sent_date = DateField()
